@@ -77,30 +77,18 @@ $("#toggle-definitions").click(function () {
   }
 });
 
-// Smooth scroll
-$('a').click(function(){
-    $('html, body').animate({
-        scrollTop: $( $.attr(this, 'href') ).offset().top
-    }, 500);
-    return false;
-});
-
-// Change character image on refresh
-// Add file names and captions to doc-characters.json
-$.getJSON('common/js/doc-characters.json', function(data) {
-  var item = data.images[Math.floor(Math.random()*data.images.length)];
-  $('<img src="common/images/docs/' + item.image + '">').appendTo('#superuser-img');
-  $('<p>' + item.caption + '<strong>OpenStack Operator</strong></p>').appendTo('#superuser-img');
-});
-
 /* BB 150310
    openstackdocstheme provides three types of admonitions, important, note
    and warning. We decorate their title paragraphs with Font Awesome icons
    by adding the appropriate FA classes.                               */
 
-$('div.important > p.admonition-title').prepend('<div class="fa fa-check-circle">&nbsp;</div>');
-$('div.note > p.admonition-title').prepend('<div class="fa fa-check-circle">&nbsp;</div>');
-$('div.warning > p.admonition-title').prepend('<div class="fa fa-exclamation-triangle">&nbsp;</div>');
+$('div.important > p.admonition-title').prepend('<div class="fa fa-fw fa-check-circle">&nbsp;</div>');
+$('div.note > p.admonition-title').prepend('<div class="fa fa-fw fa-check-circle">&nbsp;</div>');
+$('div.seealso > p.admonition-title').prepend('<div class="fa fa-fw fa-info-circle">&nbsp;</div>');
+$('div.warning > p.admonition-title').prepend('<div class="fa fa-fw fa-exclamation-triangle">&nbsp;</div>');
+$('div.versionadded > p').prepend('<div class="fa fa-fw fa-plus-circle">&nbsp;</div>');
+$('div.versionchanged > p').prepend('<div class="fa fa-fw fa-info-circle">&nbsp;</div>');
+$('div.deprecated > p').prepend('<div class="fa fa-fw fa-minus-circle">&nbsp;</div>');
 
 /* BB 150310
    We also insert a space between the icon and the admonition title
@@ -117,13 +105,35 @@ $('div.warning > p.admonition-title').prepend('<div class="fa fa-exclamation-tri
 // Launchpad with pre-filled information such as git SHA, git.openstack.org
 // source URL, published document URL and tag.
 function logABug(bugTitle, bugProject, fieldComment, fieldTags) {
+
     var lineFeed = "%0A";
-    var urlBase = "https://bugs.launchpad.net/" + bugProject + "/+filebug?field.title="
+
+    var bugChecklist = "This bug tracker is for errors with the documentation, " +
+        "use the following as a template and remove or add fields as " +
+        "you see fit. Convert [ ] into [x] to check boxes:" + lineFeed + lineFeed +
+        "- [ ] This doc is inaccurate in this way: ______" + lineFeed +
+        "- [ ] This is a doc addition request." + lineFeed +
+        "- [ ] I have a fix to the document that I can paste below including example: " +
+        "input and output. " + lineFeed + lineFeed +
+        "If you have a troubleshooting or support issue, use the following " +
+        " resources:" + lineFeed + lineFeed +
+        " - Ask OpenStack: http://ask.openstack.org" + lineFeed +
+        " - The mailing list: http://lists.openstack.org" + lineFeed +
+        " - IRC: 'openstack' channel on Freenode"+ lineFeed;
+
+    var urlBase = "https://bugs.launchpad.net/" + bugProject + "/+filebug?field.title=";
     var currentURL = "URL: " + window.location.href;
-    var bugLink = urlBase  + encodeURIComponent(bugTitle) +
-        "&field.comment=" + lineFeed + lineFeed + "-----------------------------------" + lineFeed + fieldComment +
+    var bugLink = "";
+    if (useStoryboard) {
+        var urlBase = "https://storyboard.openstack.org/#!/project/";
+        bugLink = urlBase + bugProject;
+    } else {
+        bugLink = urlBase  + encodeURIComponent(bugTitle) +
+        "&field.comment=" + lineFeed + lineFeed +  lineFeed +
+        bugChecklist + lineFeed + "-----------------------------------" + lineFeed + fieldComment +
         lineFeed + currentURL +
         "&field.tags=" + fieldTags;
+    }
     document.getElementById("logABugLink1").href=bugLink;
     document.getElementById("logABugLink2").href=bugLink;
     document.getElementById("logABugLink3").href=bugLink;
